Exception: UState::Server::Error
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- UState::Server::Error
- Defined in:
- lib/ustate/server.rb
Overview
A server binds together Backends, an Index, and Sinks.
- Backends spawn Connections with EM.
- Connections receive messages from clients, and pass States to the Index.
- The Index aggregates states together and informs Sinks.